==> rivendell-2.19.0.tar.gz: rivendell-2.19.0/rdlogin/rdlogin_nn.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDLogin - Station:</source>
        <translation>RDLogin - stasjon:</translation>
    </message>
    <message>
        <source>rdlogin : </source>
        <translation>rdlogin:</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Greier ikkje kopla til</translation>
    </message>
    <message>
        <source>Current User: unknown</source>
        <translation>Brukarnamn no: ukjent</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>Br&amp;ukarnamn</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Passord:</translation>
    </message>
    <message>
        <source>&amp;Set User</source>
        <translation>&amp;Set brukar</translation>
    </message>
    <message>
        <source>&amp;Default
User</source>
        <translation>Stan&amp;dard-
brukar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Current User:</source>
        <translation>Brukarnamn no:</translation>
    </message>
    <message>
        <source>RDLogin</source>
        <translation>RDLogin</translation>
    </message>
    <message>
        <source>Invalid Password!</source>
        <translation type="obsolete">Ugyldig passord!</translation>
    </message>
    <message>
        <source>Invalid Username or Password!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> rivendell-3.2.1.tar.gz: rivendell-3.2.1/rdlogin/rdlogin_nn.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>MainWidget</name>
    <message>
        <source>RDLogin - Station:</source>
        <translation type="obsolete">RDLogin - stasjon:</translation>
    </message>
    <message>
        <source>rdlogin : </source>
        <translation type="obsolete">rdlogin:</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="obsolete">Greier ikkje kopla til</translation>
    </message>
    <message>
        <source>Current User: unknown</source>
        <translation>Brukarnamn no: ukjent</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>Br&amp;ukarnamn</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Passord:</translation>
    </message>
    <message>
        <source>&amp;Set User</source>
        <translation>&amp;Set brukar</translation>
    </message>
    <message>
        <source>&amp;Default
User</source>
        <translation>Stan&amp;dard-
brukar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Current User:</source>
        <translation type="obsolete">Brukarnamn no:</translation>
    </message>
    <message>
        <source>RDLogin</source>
        <translation>RDLogin</translation>
    </message>
    <message>
        <source>Invalid Password!</source>
        <translation type="obsolete">Ugyldig passord!</translation>
    </message>
    <message>
        <source>Invalid Username or Password!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current User</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
